#::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
#modelling the effect of (1) parasite load on RMR and (2) RMR on DEE
#For the paper ' The role of Parasitism in the energy management of a free ranging bird'
#Authors: Olivia Hicks 1 *, Sarah J. Burthe 2, Francis Daunt 2, Mark Newell 2, Olivier Chastel 3, Charline Parenteau 3, Jonathan A. Green 1
#http://dx.doi.org/10.1242/jeb.190066 

#1 School of Environmental Sciences, University of Liverpool, Liverpool L69 3GP, UK
#2 Centre for Ecology & Hydrology, Bush Estate, Penicuik, Midlothian, EH26 0QB, UK
#3 Centre d'Etudes Biologiques de Chizé, UMR 7372, CNRS-Université La Rochelle, France

#*corresponding author och@liv.ac.uk 
#::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::


#:::::::::::::::::::::::::::::::::::::::::::
#LOAD PACKAGES####
#:::::::::::::::::::::::::::::::::::::::::::
req_pkgs<-c('ggplot2','cowplot','lme4',
            'dplyr','car','plyr','lubridate',
            'MuMIn','LMERConvenienceFunctions','AICcmodavg','forcats')#allows use of predictSE 


#Install packages that are not already installed
if(length(setdiff(req_pkgs, rownames(installed.packages()))) > 0) {
  install.packages(setdiff(req_pkgs, rownames(installed.packages())))
} 

lapply(req_pkgs,require, character.only = TRUE)


#::::::::::::::::::::::::::::::::::::::::
#LOAD IN DATA ####
#::::::::::::::::::::::::::::::::::::::::

birds<-read.csv('T3_data.csv')

#::::::::::::::::::::::::::::::::::::::
#T3 MODELS####
#::::::::::::::::::::::::::::::::::::::
birds.bm$mean_prod<-as.numeric(birds.bm$mean_prod)
birds$BirdID<-as.factor(birds$BirdID)
birds$BirdID<-as.factor(birds$Year)

#FEMALES
fem.T3.mod<-lmer(sc.T3.1 ~ 
                   sc.count_num*sc.SinceHatch
                 +sc.count_num*sc.fledglings
                 +sc.BM.g.
                 +sc.Age +I(sc.Age^2)
                 +Year
                 +(1|BirdID),data = birds.bm[birds.bm$Sex=='F',],REML=FALSE)

#MALES
mal.T3.mod<-lmer(sc.T3.1 ~ 
                   sc.count_num*sc.SinceHatch
                 +sc.count_num*sc.fledglings
                 +sc.BM.g.
                 +sc.Age+I(sc.Age^2) 
                 +(1|Year)
                 +(1|BirdID), data = birds.bm[birds.bm$Sex=='M',],REML=FALSE)


#DEE and T3####
#:::::::::::::::::::::::::::::::::::::::::::
DEE.data$sc.DEE <-(DEE.data$DEE.L.Day-mean(DEE.data$DEE.L.Day))/sd(DEE.data$DEE.L.Day)#using correct scale
DEE.data$sc.fly <-(DEE.data$fly-mean(DEE.data$fly))/sd(DEE.data$fly)#using correct scale

DEE.data$mean_prod<-as.factor(DEE.data$mean_prod)

#female
fem.mod<-lmer(sc.DEE ~ 
                +sc.T3.1*sc.SinceHatch
              +sc.T3.1*sc.fledglings
              +sc.BM.g.
              +sc.Age 
              +Year
              +(1|BirdID),data = DEE.data[DEE.data$Sex=='F',])
#male
mal.mod<-lmer(sc.DEE ~ 
                +sc.T3.1*sc.SinceHatch
              +sc.T3.1*sc.fledglings
              +sc.BM.g.
              +sc.Age 
              +Year
              +(1|BirdID),data = DEE.data[DEE.data$Sex=='M',])

